simplify.Authentication

Package simplify :: Class Authentication |
[hide private]
[frames] | no frames]

# Class Authentication

source code

Holds authentication information used when accessing the API.

Instance Methods | [hide private]
__init__(self, **kwargs) Constructs an Authentication object. | source code

Instance Variables | [hide private]
| access_token OAuth token used to access the API.
| private_key Private key used to access the API.
| public_key Public key used to access the API.

Method Details | [hide private]

### __init__(self, **kwargs) (Constructor) | source code
Constructs an Authentication object. Parameters: `kwargs` - contains initial values for the instance variables. Valid keywords are public_key, private_key and access_token. If no value is passed for public_key or its value is None then simplify.public_key is used. If no value is passed for private_key or its value is None then simplify.private_key is used. Returns: an Authentication object